pycoda
======

.. image:: https://badge.fury.io/py/pycoda.svg?
    :target: http://badge.fury.io/py/pycoda
.. image:: https://travis-ci.org/acsone/pycoda.svg?branch=master
    :target: https://travis-ci.org/acsone/pycoda
.. image:: https://coveralls.io/repos/acsone/pycoda/badge.png?branch=master 
    :target: https://coveralls.io/r/acsone/pycoda?branch=master
.. image:: https://pypip.in/license/pycoda/badge.svg
    :target: https://pypi.python.org/pypi/pycoda/
    :alt: License

A python library for parsing CODA files

- Code repository: http://github.com/acsone/pycoda
- Report bugs at http://github.com/acsone/pycoda/issues

Authors:

 * Laurent Mignon (ACSONE)


